@@ -81,8 +81,8 @@ def _bytes_from_json(value, field):
 def _timestamp_from_json(value, field):
     """Coerce 'value' to a datetime, if set or not nullable."""
     if _not_null(value, field):
-        # value will be a float in seconds, to microsecond precision, in UTC.
-        return _datetime_from_microseconds(1e6 * float(value))
+        # value will be a integer in seconds, to microsecond precision, in UTC.
+        return _datetime_from_microseconds(int(value))
 
 
 def _timestamp_query_param_from_json(value, field):
@@ -188,6 +188,7 @@ _CELLDATA_FROM_JSON = {
     "FLOAT": _float_from_json,
     "FLOAT64": _float_from_json,
     "NUMERIC": _decimal_from_json,
+    "BIGNUMERIC": _decimal_from_json,
     "BOOLEAN": _bool_from_json,
     "BOOL": _bool_from_json,
     "STRING": _string_from_json,
@@ -347,6 +348,7 @@ _SCALAR_VALUE_TO_JSON_ROW = {
     "FLOAT": _float_to_json,
     "FLOAT64": _float_to_json,
     "NUMERIC": _decimal_to_json,
+    "BIGNUMERIC": _decimal_to_json,
     "BOOLEAN": _bool_to_json,
     "BOOL": _bool_to_json,
     "BYTES": _bytes_to_json,
